@@ -1,7 +1,7 @@
 package Catalyst::Plugin::VersionedURI;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: add version component to uris
-$Catalyst::Plugin::VersionedURI::VERSION = '1.1.2';
+$Catalyst::Plugin::VersionedURI::VERSION = '1.2.0';
 
 use 5.10.0;
 
@@ -85,15 +85,14 @@ around uri_for => sub {
     my $uris_re = $self->versioned_uri_regex
         or return $uri;
 
-    my $base = $self->req->base;
-    $base =~ s#(?<!/)$#/#;  # add trailing '/'
-
-    return $uri unless $$uri =~  m#(^\Q$base\E$uris_re)#;
+    return $uri unless $uri->path =~ m#^/($uris_re)#;
 
     my $version = $self->uri_version( $uri, @args );
 
     if ( state $in_path = $self->config->{'Plugin::VersionedURI'}{in_path} ) {
-        $$uri =~ s#(^\Q$base\E$uris_re)#${1}v$version/#;
+        my $path = $uri->path;
+        $path =~ s#^/($uris_re)#${1}v$version/#;
+        $uri->path( $path );
     } 
     else {
         state $version_name = $self->config->{'Plugin::VersionedURI'}{param} || 'v';
@@ -117,7 +116,7 @@ Catalyst::Plugin::VersionedURI - add version component to uris
 
 =head1 VERSION
 
-version 1.1.2
+version 1.2.0
 
 =head1 SYNOPSIS
 
